@@ -252,18 +252,14 @@ boolean D_Display (void)
     // the HUD is drawn on top of everything else
     if (gamestate == GS_LEVEL && gametic && !(automapactive && crispy->automapoverlay))
 	HU_Drawer ();
-
-    // [crispy] demo progress bar
-    if (demoplayback && crispy->demobar)
-    {
-	extern void HU_DemoProgressBar (void);
-
-	HU_DemoProgressBar();
-    }
     
     // clean up border stuff
     if (gamestate != oldgamestate && gamestate != GS_LEVEL)
+#ifndef CRISPY_TRUECOLOR
 	I_SetPalette (W_CacheLumpName (DEH_String("PLAYPAL"),PU_CACHE));
+#else
+	I_SetPalette (0);
+#endif
 
     // see if the border needs to be initially drawn
     if (gamestate == GS_LEVEL && oldgamestate != GS_LEVEL)
@@ -415,6 +411,8 @@ void D_BindVariables(void)
     }
 
     // [crispy] bind "crispness" config variables
+    M_BindIntVariable("crispy_automapoverlay",  &crispy->automapoverlay);
+    M_BindIntVariable("crispy_automaprotate",   &crispy->automaprotate);
     M_BindIntVariable("crispy_automapstats",    &crispy->automapstats);
     M_BindIntVariable("crispy_brightmaps",      &crispy->brightmaps);
     M_BindIntVariable("crispy_centerweapon",    &crispy->centerweapon);
@@ -448,6 +446,9 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
     M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
     M_BindIntVariable("crispy_translucency",    &crispy->translucency);
+#ifdef CRISPY_TRUECOLOR
+    M_BindIntVariable("crispy_truecolor",       &crispy->truecolor);
+#endif
     M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
     M_BindIntVariable("crispy_vsync",           &crispy->vsync);
     M_BindIntVariable("crispy_weaponsquat",     &crispy->weaponsquat);
@@ -1314,6 +1315,154 @@ static void LoadIwadDeh(void)
     }
 }
 
+// [crispy] support loading SIGIL.WAD (and SIGIL_SHREDS.WAD) alongside DOOM.WAD
+static void LoadSigilWad(void)
+{
+    int i;
+
+    struct {
+        const char *name;
+        const char new_name[8];
+    } sigil_lumps [] = {
+        {"CREDIT",   "SIGCREDI"},
+        {"HELP1",    "SIGHELP1"},
+        {"TITLEPIC", "SIGTITLE"},
+        {"DEHACKED", "SIG_DEH"},
+        {"DEMO1",    "SIGDEMO1"},
+        {"DEMO2",    "SIGDEMO2"},
+        {"DEMO3",    "SIGDEMO3"},
+        {"DEMO4",    "SIGDEMO4"},
+        {"D_INTER",  "D_SIGINT"},
+        {"D_INTRO",  "D_SIGTIT"},
+    };
+
+    const char *const texture_files[] = {
+        "PNAMES",
+        "TEXTURE1",
+        "TEXTURE2",
+    };
+
+    // [crispy] don't load SIGIL.wad if another PWAD already provides E5M1
+    i = W_CheckNumForName("E5M1");
+    if (i != -1)
+    {
+        return;
+    }
+
+    // [crispy] don't load SIGIL.wad if SIGIL_COMPAT.wad is already loaded
+    i = W_CheckNumForName("E3M1");
+    if (i != -1 && !strncasecmp(W_WadNameForLump(lumpinfo[i]), "SIGIL_COMPAT", 12))
+    {
+        return;
+    }
+
+    // [crispy] don't load SIGIL.wad if another PWAD already modifies the texture files
+    for (i = 0; i < arrlen(texture_files); i++)
+    {
+        int j;
+
+        j = W_CheckNumForName(texture_files[i]);
+
+        if (j != -1 && !W_IsIWADLump(lumpinfo[j]))
+        {
+            return;
+        }
+    }
+
+    if (gameversion == exe_ultimate)
+    {
+        const char *const sigil_wads[] = {
+            "SIGIL_v1_21.wad",
+            "SIGIL_v1_2.wad",
+            "SIGIL.wad"
+        };
+        char *sigil_wad = NULL, *sigil_shreds = NULL;
+        char *dirname;
+
+        dirname = M_DirName(iwadfile);
+        sigil_shreds = M_StringJoin(dirname, DIR_SEPARATOR_S, "SIGIL_SHREDS.wad", NULL);
+
+        // [crispy] load SIGIL.WAD
+        for (i = 0; i < arrlen(sigil_wads); i++)
+        {
+            sigil_wad = M_StringJoin(dirname, DIR_SEPARATOR_S, sigil_wads[i], NULL);
+
+            if (M_FileExists(sigil_wad))
+            {
+                break;
+            }
+
+            free(sigil_wad);
+            sigil_wad = D_FindWADByName(sigil_wads[i]);
+
+            if (sigil_wad)
+            {
+                break;
+            }
+        }
+        free(dirname);
+
+        if (sigil_wad == NULL)
+        {
+            free(sigil_shreds);
+            return;
+        }
+
+        printf(" [expansion]");
+        D_AddFile(sigil_wad);
+        free(sigil_wad);
+
+        // [crispy] load SIGIL_SHREDS.WAD
+        if (!M_FileExists(sigil_shreds))
+        {
+            free(sigil_shreds);
+            sigil_shreds = D_FindWADByName("SIGIL_SHREDS.wad");
+        }
+
+        if (sigil_shreds != NULL)
+        {
+            printf(" [expansion]");
+            D_AddFile(sigil_shreds);
+            free(sigil_shreds);
+        }
+
+        // [crispy] rename intrusive SIGIL_SHREDS.wad music lumps out of the way
+        for (i = 0; i < arrlen(sigil_lumps); i++)
+        {
+            int j;
+
+            // [crispy] skip non-music lumps
+            if (strncasecmp(sigil_lumps[i].name, "D_", 2))
+            {
+                continue;
+            }
+
+            j = W_CheckNumForName(sigil_lumps[i].name);
+
+            if (j != -1 && !strncasecmp(W_WadNameForLump(lumpinfo[j]), "SIGIL_SHREDS", 12))
+            {
+                memcpy(lumpinfo[j]->name, sigil_lumps[i].new_name, 8);
+            }
+        }
+
+        // [crispy] rename intrusive SIGIL.wad graphics, demos and music lumps out of the way
+        for (i = 0; i < arrlen(sigil_lumps); i++)
+        {
+            int j;
+
+            j = W_CheckNumForName(sigil_lumps[i].name);
+
+            if (j != -1 && !strncasecmp(W_WadNameForLump(lumpinfo[j]), "SIGIL", 5))
+            {
+                memcpy(lumpinfo[j]->name, sigil_lumps[i].new_name, 8);
+            }
+        }
+
+        // [crispy] regenerate the hashtable
+        W_GenerateHashTable();
+    }
+}
+
 // [crispy] support loading NERVE.WAD alongside DOOM2.WAD
 static void LoadNerveWad(void)
 {
@@ -1365,6 +1514,7 @@ static void LoadNerveWad(void)
             return;
         }
 
+        printf(" [expansion]");
         D_AddFile(nervewadfile);
 
         // [crispy] rename level name patch lumps out of the way
@@ -1375,6 +1525,9 @@ static void LoadNerveWad(void)
             M_snprintf (lumpname, 9, "CWILV%2.2d", i);
             lumpinfo[W_GetNumForName(lumpname)]->name[0] = 'N';
         }
+
+        // [crispy] regenerate the hashtable
+        W_GenerateHashTable();
     }
 }
 
@@ -1614,7 +1767,7 @@ void D_DoomMain (void)
     M_LoadDefaults();
 
     // Save configuration at exit.
-    I_AtExit(M_SaveDefaults, false);
+    I_AtExit(M_SaveDefaults, true); // [crispy] always save configuration at exit
 
     // Find main IWAD file and load it.
     iwadfile = D_FindIWAD(IWAD_MASK_DOOM, &gamemission);
@@ -1719,6 +1872,19 @@ void D_DoomMain (void)
     if (!M_ParmExists("-noautoload") && gamemode != shareware)
     {
         char *autoload_dir;
+
+        // common auto-loaded files for all Doom flavors
+
+        if (gamemission < pack_chex)
+        {
+            autoload_dir = M_GetAutoloadDir("doom-all");
+            DEH_AutoLoadPatches(autoload_dir);
+            W_AutoLoadWADs(autoload_dir);
+            free(autoload_dir);
+        }
+
+        // auto-loaded files per IWAD
+
         autoload_dir = M_GetAutoloadDir(D_SaveGameIWADName(gamemission));
         DEH_AutoLoadPatches(autoload_dir);
         W_AutoLoadWADs(autoload_dir);
@@ -1729,63 +1895,12 @@ void D_DoomMain (void)
     // Note that there's a very careful and deliberate ordering to how
     // Dehacked patches are loaded. The order we use is:
     //  1. IWAD dehacked patches.
-    // [crispy] 1.a. dehacked patches in the config directory following
-    // the preload?.deh/.bex naming scheme are preloaded at game startup
-    if (!M_ParmExists("-nodeh") && !M_ParmExists("-noload"))
-    {
-	int i;
-
-	for (i = 0; i < 10; i++)
-	{
-	    char *path;
-
-	    M_snprintf(file, sizeof(file), "preload%d.deh", i);
-	    path = M_StringJoin(configdir, file, NULL);
-
-	    if (M_FileExists(path))
-		DEH_LoadFile(path);
-	    else
-	    {
-		free(path);
-		M_snprintf(file, sizeof(file), "preload%d.bex", i);
-		path = M_StringJoin(configdir, file, NULL);
-
-		if (M_FileExists(path))
-		    DEH_LoadFile(path);
-	    }
-	    free(path);
-	}
-    }
     //  2. Command line dehacked patches specified with -deh.
     //  3. PWAD dehacked patches in DEHACKED lumps.
     DEH_ParseCommandLine();
 
-    // [crispy] PWAD files in the config directory following
-    // the preload?.wad naming scheme are preloaded at game startup
-    if (!M_ParmExists("-noload") && gamemode != shareware)
-    {
-	int i;
-	extern void W_MergeFile(char *filename);
-
-	for (i = 0; i < 10; i++)
-	{
-	    char *path;
-
-	    M_snprintf(file, sizeof(file), "preload%d.wad", i);
-	    path = M_StringJoin(configdir, file, NULL);
-
-	    if (M_FileExists(path))
-	    {
-		modifiedgame = true;
-		printf(" auto-merging %s !\n", path);
-		W_MergeFile(path);
-	    }
-	    free(path);
-	}
-    }
-
     // Load PWAD files.
-    modifiedgame |= W_ParseCommandLine(); // [crispy] OR'ed
+    modifiedgame = W_ParseCommandLine();
 
     //!
     // @arg <file>
@@ -1891,10 +2006,11 @@ void D_DoomMain (void)
     W_GenerateHashTable();
 
     // [crispy] allow overriding of special-casing
-    if (!M_ParmExists("-nodeh"))
+    if (!M_ParmExists("-noautoload") && gamemode != shareware)
     {
 	LoadMasterlevelsWad();
 	LoadNerveWad();
+	LoadSigilWad();
     }
 
     // Load DEHACKED lumps from WAD files - but only if we give the right
@@ -2001,6 +2117,12 @@ void D_DoomMain (void)
         )
     );
 
+    // [crispy] check for presence of a 5th episode
+    crispy->haved1e5 = (gameversion == exe_ultimate) &&
+                       (W_CheckNumForName("m_epi5") != -1) &&
+                       (W_CheckNumForName("e5m1") != -1) &&
+                       (W_CheckNumForName("wilv40") != -1);
+
     // [crispy] check for presence of E1M10
     crispy->havee1m10 = (gamemode == retail) &&
                        (W_CheckNumForName("e1m10") != -1) &&
@@ -2012,7 +2134,7 @@ void D_DoomMain (void)
                        (W_CheckNumForName("cwilv32") != -1);
 
     // [crispy] change level name for MAP33 if not already changed
-    if (crispy->havemap33 && !strcmp(PHUSTR_1, DEH_String(PHUSTR_1)))
+    if (crispy->havemap33 && !DEH_HasStringReplacement(PHUSTR_1))
     {
         DEH_AddStringReplacement(PHUSTR_1, "level 33: betray");
     }
