@@ -813,6 +813,11 @@ void P_RespawnSpecials (void)
 // [crispy] weapon sound sources
 degenmobj_t muzzles[MAXPLAYERS];
 
+mobj_t *Crispy_PlayerSO (int p)
+{
+	return crispy->soundfull ? (mobj_t *) &muzzles[p] : players[p].mo;
+}
+
 //
 // P_SpawnPlayer
 // Called when a player is spawned on the level.
@@ -868,7 +873,7 @@ void P_SpawnPlayer (mapthing_t* mthing)
     p->viewheight = VIEWHEIGHT;
 
     // [crispy] weapon sound source
-    p->so = crispy->soundfull ? (mobj_t *) &muzzles[mthing->type-1] : p->mo;
+    p->so = Crispy_PlayerSO(mthing->type-1);
 
     // setup gun psprite
     P_SetupPsprites (p);
@@ -927,6 +932,7 @@ void P_SpawnMapThing (mapthing_t* mthing)
     {
 	// save spots for respawning in network games
 	playerstarts[mthing->type-1] = *mthing;
+	playerstartsingame[mthing->type-1] = true;
 	if (!deathmatch)
 	    P_SpawnPlayer (mthing);
 
@@ -1027,6 +1033,16 @@ void P_SpawnMapThing (mapthing_t* mthing)
     {
 	mobj->flags |= (Crispy_Random() & 3) << MF_TRANSSHIFT;
     }
+
+    // [crispy] blinking key or skull in the status bar
+    if (mobj->sprite == SPR_BSKU)
+	st_keyorskull[it_bluecard] = 3;
+    else
+    if (mobj->sprite == SPR_RSKU)
+	st_keyorskull[it_redcard] = 3;
+    else
+    if (mobj->sprite == SPR_YSKU)
+	st_keyorskull[it_yellowcard] = 3;
 }
 
 
