@@ -34,6 +34,7 @@
 #include "m_misc.h"
 #include "m_random.h"
 #include "w_wad.h"
+#include "r_swirl.h" // [crispy] R_InitDistortedFlats()
 
 #include "r_local.h"
 #include "p_local.h"
@@ -151,6 +152,7 @@ extern  line_t*	linespeciallist[MAXLINEANIMS];
 void P_InitPicAnims (void)
 {
     int		i;
+    boolean init_swirl = false;
 
     // [crispy] add support for ANIMATED lumps
     animdef_t *animdefs;
@@ -203,18 +205,29 @@ void P_InitPicAnims (void)
 
 	lastanim->istexture = animdefs[i].istexture;
 	lastanim->numpics = lastanim->picnum - lastanim->basepic + 1;
+	lastanim->speed = from_lump ? LONG(animdefs[i].speed) : animdefs[i].speed;
 
+	// [crispy] add support for SMMU swirling flats
+	if (lastanim->speed > 65535 || lastanim->numpics == 1)
+	{
+		init_swirl = true;
+	}
+	else
 	if (lastanim->numpics < 2)
 	    I_Error ("P_InitPicAnims: bad cycle from %s to %s",
 		     startname, endname);
 	
-	lastanim->speed = from_lump ? LONG(animdefs[i].speed) : animdefs[i].speed;
 	lastanim++;
     }
 	
     if (from_lump)
     {
-	Z_ChangeTag(animdefs, PU_CACHE);
+	W_ReleaseLumpName("ANIMATED");
+    }
+
+    if (init_swirl)
+    {
+	R_InitDistortedFlats();
     }
 }
 
@@ -492,8 +505,8 @@ P_FindSectorFromLineTag
 {
     int	i;
 	
+#if 0
     // [crispy] linedefs without tags apply locally
-/*
     if (crispy->singleplayer && !line->tag)
     {
     for (i=start+1;i<numsectors;i++)
@@ -505,7 +518,15 @@ P_FindSectorFromLineTag
 	}
     }
     else
-*/
+#else
+    // [crispy] emit a warning for linedefs without tags
+    if (!line->tag)
+    {
+        const long linedef = line - lines;
+        fprintf(stderr, "P_FindSectorFromLineTag: Linedef %ld without tag\n", linedef);
+    }
+#endif
+
     for (i=start+1;i<numsectors;i++)
 	if (sectors[i].tag == line->tag)
 	    return i;
@@ -1131,19 +1152,21 @@ void P_PlayerInSpecialSector (player_t* player)
 			
       case 9:
 	// SECRET SECTOR
+	player->secretcount++;
 	// [crispy] show centered "Secret Revealed!" message
-	if (showMessages && crispy->secretmessage)
+	if (showMessages && crispy->secretmessage && player == &players[consoleplayer])
 	{
 	    int sfx_id;
+	    static char str_count[32];
+
+	    M_snprintf(str_count, sizeof(str_count), "Secret %d of %d revealed!", player->secretcount, totalsecret);
 
 	    // [crispy] play DSSECRET if available
 	    sfx_id = I_GetSfxLumpNum(&S_sfx[sfx_secret]) != -1 ? sfx_secret : sfx_itmbk;
 
-	    player->centermessage = HUSTR_SECRETFOUND;
-	    if (player == &players[consoleplayer])
-	        S_StartSound(NULL, sfx_id);
+	    player->centermessage = (crispy->secretmessage == SECRETMESSAGE_COUNT) ? str_count : HUSTR_SECRETFOUND;
+	    S_StartSound(NULL, sfx_id);
 	}
-	player->secretcount++;
 	// [crispy] remember revealed secrets
 	sector->oldspecial = sector->special;
 	sector->special = 0;
@@ -1520,6 +1543,19 @@ int EV_DoDonut(line_t*	line)
 short		numlinespecials;
 line_t*		linespeciallist[MAXLINEANIMS];
 
+static unsigned int NumScrollers()
+{
+    unsigned int i, scrollers = 0;
+
+    for (i = 0; i < numlines; i++)
+    {
+        if (48 == lines[i].special)
+        {
+            scrollers++;
+        }
+    }
+    return scrollers;
+}
 
 // Parses command line parameters.
 void P_SpawnSpecials (void)
@@ -1615,8 +1651,8 @@ void P_SpawnSpecials (void)
 	  case 85: // [crispy] [JN] (Boom) Scroll Texture Right
             if (numlinespecials >= MAXLINEANIMS)
             {
-                I_Error("Too many scrolling wall linedefs! "
-                        "(Vanilla limit is 64)");
+                I_Error("Too many scrolling wall linedefs (%d)! "
+                        "(Vanilla limit is 64)", NumScrollers());
             }
 	    // EFFECT FIRSTCOL SCROLL+
 	    linespeciallist[numlinespecials] = &lines[i];
