@@ -765,8 +765,17 @@ void R_InitTextures (void)
     {
 	for (j = 0; j < pnameslumps[i].nummappatches; j++)
 	{
+	    int p, po;
+
 	    M_StringCopy(name, pnameslumps[i].name_p + j * 8, sizeof(name));
-	    patchlookup[k++] = W_CheckNumForName(name);
+	    p = po = W_CheckNumForName(name);
+	    // [crispy] prevent flat lumps from being mistaken as patches
+	    while (p >= firstflat && p <= lastflat)
+	    {
+		p = W_CheckNumForNameFromTo (name, p - 1, 0);
+	    }
+	    // [crispy] if the name is unambiguous, use the lump we found
+	    patchlookup[k++] = (p == -1) ? po : p;
 	}
     }
 
@@ -831,10 +840,18 @@ void R_InitTextures (void)
     if (I_ConsoleStdout())
     {
         printf("[");
+#ifndef CRISPY_TRUECOLOR
         for (i = 0; i < temp3 + 9 + 1; i++) // [crispy] one more for R_InitTranMap()
+#else
+        for (i = 0; i < temp3 + 9; i++)
+#endif
             printf(" ");
         printf("]");
+#ifndef CRISPY_TRUECOLOR
         for (i = 0; i < temp3 + 10 + 1; i++) // [crispy] one more for R_InitTranMap()
+#else
+        for (i = 0; i < temp3 + 10; i++)
+#endif
             printf("\b");
     }
 	
@@ -988,6 +1005,7 @@ void R_InitSpriteLumps (void)
     }
 }
 
+#ifndef CRISPY_TRUECOLOR
 // [crispy] initialize translucency filter map
 // based in parts on the implementation from boom202s/R_DATA.C:676-787
 
@@ -995,9 +1013,9 @@ enum {
     r, g, b
 } rgb_t;
 
-int tran_filter_pct = 66;
+static const int tran_filter_pct = 66;
 
-void R_InitTranMap()
+static void R_InitTranMap()
 {
     int lump = W_CheckNumForName("TRANMAP");
 
@@ -1104,21 +1122,90 @@ void R_InitTranMap()
 
 	free(fname);
 
-	Z_ChangeTag(playpal, PU_CACHE);
+	W_ReleaseLumpName("PLAYPAL");
     }
 }
+#endif
 
 //
 // R_InitColormaps
 //
 void R_InitColormaps (void)
 {
+#ifndef CRISPY_TRUECOLOR
     int	lump;
 
     // Load in the light tables, 
     //  256 byte align tables.
     lump = W_GetNumForName(DEH_String("COLORMAP"));
     colormaps = W_CacheLumpNum(lump, PU_STATIC);
+#else
+	byte *playpal;
+	int c, i, j = 0;
+	byte r, g, b;
+	extern byte **gamma2table;
+
+	// [crispy] intermediate gamma levels
+	if (!gamma2table)
+	{
+		extern void I_SetGammaTable (void);
+		I_SetGammaTable();
+	}
+
+	playpal = W_CacheLumpName("PLAYPAL", PU_STATIC);
+
+	if (!colormaps)
+	{
+		colormaps = (lighttable_t*) Z_Malloc((NUMCOLORMAPS + 1) * 256 * sizeof(lighttable_t), PU_STATIC, 0);
+	}
+
+	if (crispy->truecolor)
+	{
+		for (c = 0; c < NUMCOLORMAPS; c++)
+		{
+			const float scale = 1. * c / NUMCOLORMAPS;
+
+			for (i = 0; i < 256; i++)
+			{
+				r = gamma2table[usegamma][playpal[3 * i + 0]] * (1. - scale) + gamma2table[usegamma][0] * scale;
+				g = gamma2table[usegamma][playpal[3 * i + 1]] * (1. - scale) + gamma2table[usegamma][0] * scale;
+				b = gamma2table[usegamma][playpal[3 * i + 2]] * (1. - scale) + gamma2table[usegamma][0] * scale;
+
+				colormaps[j++] = 0xff000000 | (r << 16) | (g << 8) | b;
+			}
+		}
+
+		// [crispy] Invulnerability (c == COLORMAPS)
+		for (i = 0; i < 256; i++)
+		{
+			const byte gray = 0xff -
+			     (byte) (0.299 * playpal[3 * i + 0] +
+			             0.587 * playpal[3 * i + 1] +
+			             0.114 * playpal[3 * i + 2]);
+			r = g = b = gamma2table[usegamma][gray];
+
+			colormaps[j++] = 0xff000000 | (r << 16) | (g << 8) | b;
+		}
+	}
+	else
+	{
+		byte *const colormap = W_CacheLumpName("COLORMAP", PU_STATIC);
+
+		for (c = 0; c <= NUMCOLORMAPS; c++)
+		{
+			for (i = 0; i < 256; i++)
+			{
+				r = gamma2table[usegamma][playpal[3 * colormap[c * 256 + i] + 0]] & ~3;
+				g = gamma2table[usegamma][playpal[3 * colormap[c * 256 + i] + 1]] & ~3;
+				b = gamma2table[usegamma][playpal[3 * colormap[c * 256 + i] + 2]] & ~3;
+
+				colormaps[j++] = 0xff000000 | (r << 16) | (g << 8) | b;
+			}
+		}
+
+		W_ReleaseLumpName("COLORMAP");
+	}
+#endif
 
     // [crispy] initialize color translation and color strings tables
     {
@@ -1147,14 +1234,16 @@ void R_InitColormaps (void)
 	    crstr[i] = M_StringDuplicate(c);
 	}
 
-	Z_ChangeTag(playpal, PU_CACHE);
+	W_ReleaseLumpName("PLAYPAL");
     }
 
+#ifndef CRISPY_TRUECOLOR
     // [crispy] initialize tinttable for V_DrawPatchShadow2
     {
 	extern byte *tinttable;
 	tinttable = cr[CR_DARK];
     }
+#endif
 }
 
 
@@ -1167,16 +1256,23 @@ void R_InitColormaps (void)
 //
 void R_InitData (void)
 {
-    R_InitBrightmaps (0);
+    // [crispy] Moved R_InitFlats() to the top, because it sets firstflat/lastflat
+    // which are required by R_InitTextures() to prevent flat lumps from being
+    // mistaken as patches and by R_InitBrightmaps() to set brightmaps for flats.
+    // R_InitBrightmaps() comes next, because it sets R_BrightmapForTexName()
+    // to initialize brightmaps depending on gameversion in R_InitTextures().
+    R_InitFlats ();
+    R_InitBrightmaps ();
     R_InitTextures ();
     printf (".");
-    R_InitFlats ();
-    R_InitBrightmaps (1);
+//  R_InitFlats (); [crispy] moved ...
     printf (".");
     R_InitSpriteLumps ();
     printf (".");
     R_InitColormaps ();
+#ifndef CRISPY_TRUECOLOR
     R_InitTranMap(); // [crispy] prints a mark itself
+#endif
 }
 
 
