@@ -107,6 +107,129 @@ static musicinfo_t *mus_playing = NULL;
 
 int snd_channels = 8;
 
+// [crispy] add support for alternative music tracks for Final Doom's
+// TNT and Plutonia as introduced in DoomMetalVol5.wad
+
+typedef struct {
+	const char *const from;
+	const char *const to;
+} altmusic_t;
+
+static const altmusic_t altmusic_tnt[] =
+{
+	{"runnin", "sadist"}, // MAP01
+	{"stalks", "burn"},   // MAP02
+	{"countd", "messag"}, // MAP03
+	{"betwee", "bells"},  // MAP04
+	{"doom",   "more"},   // MAP05
+	{"the_da", "agony"},  // MAP06
+	{"shawn",  "chaos"},  // MAP07
+	{"ddtblu", "beast"},  // MAP08
+	{"in_cit", "sadist"}, // MAP09
+	{"dead",   "infini"}, // MAP10
+	{"stlks2", "kill"},   // MAP11
+	{"theda2", "ddtbl3"}, // MAP12
+	{"doom2",  "bells"},  // MAP13
+	{"ddtbl2", "cold"},   // MAP14
+	{"runni2", "burn2"},  // MAP15
+	{"dead2",  "blood"},  // MAP16
+	{"stlks3", "more"},   // MAP17
+	{"romero", "infini"}, // MAP18
+	{"shawn2", "countd"}, // MAP19
+	{"messag", "horizo"}, // MAP20
+	{"count2", "in_cit"}, // MAP21
+	{"ddtbl3", "aim"},    // MAP22
+//	{"ampie",  "ampie"},  // MAP23
+	{"theda3", "betwee"}, // MAP24
+	{"adrian", "doom"},   // MAP25
+	{"messg2", "blood"},  // MAP26
+	{"romer2", "beast"},  // MAP27
+	{"tense",  "aim"},    // MAP28
+	{"shawn3", "bells"},  // MAP29
+	{"openin", "beast"},  // MAP30
+//	{"evil",   "evil"},   // MAP31
+	{"ultima", "in_cit"}, // MAP32
+	{NULL,     NULL},
+};
+
+// Plutonia music is completely taken from Doom 1 and 2, but re-arranged.
+// That is, Plutonia's D_RUNNIN (for MAP01) is the renamed D_E1M2. So,
+// it makes sense to play the D_E1M2 replacement from DoomMetal in Plutonia.
+
+static const altmusic_t altmusic_plut[] =
+{
+	{"runnin", "e1m2"},   // MAP01
+	{"stalks", "e1m3"},   // MAP02
+	{"countd", "e1m6"},   // MAP03
+	{"betwee", "e1m4"},   // MAP04
+	{"doom",   "e1m9"},   // MAP05
+	{"the_da", "e1m8"},   // MAP06
+	{"shawn",  "e2m1"},   // MAP07
+	{"ddtblu", "e2m2"},   // MAP08
+	{"in_cit", "e3m3"},   // MAP09
+	{"dead",   "e1m7"},   // MAP10
+	{"stlks2", "bunny"},  // MAP11
+	{"theda2", "e3m8"},   // MAP12
+	{"doom2",  "e3m2"},   // MAP13
+	{"ddtbl2", "e2m8"},   // MAP14
+	{"runni2", "e2m7"},   // MAP15
+	{"dead2",  "e3m1"},   // MAP16
+	{"stlks3", "e1m1"},   // MAP17
+	{"romero", "e2m5"},   // MAP18
+	{"shawn2", "e1m5"},   // MAP19
+//	{"messag", "messag"}, // MAP20
+//	{"count2", "count2"}, // MAP21 (d_read_m has no instumental cover in Doom Metal)
+//	{"ddtbl3", "ddtbl3"}, // MAP22
+//	{"ampie",  "ampie"},  // MAP23
+//	{"theda3", "theda3"}, // MAP24
+//	{"adrian", "adrian"}, // MAP25
+//	{"messg2", "messg2"}, // MAP26
+	{"romer2", "e2m1"},   // MAP27
+	{"tense",  "e2m2"},   // MAP28
+	{"shawn3", "e1m1"},   // MAP29
+//	{"openin", "openin"}, // MAP30 (d_victor has no instumental cover in Doom Metal)
+	{"evil",   "e3m4"},   // MAP31
+	{"ultima", "e2m8"},   // MAP32
+	{NULL,     NULL},
+};
+
+static void S_RegisterAltMusic()
+{
+	const altmusic_t *altmusic_fromto, *altmusic;
+
+	if (gamemission == pack_tnt)
+	{
+		altmusic_fromto = altmusic_tnt;
+	}
+	else
+	if (gamemission == pack_plut)
+	{
+		altmusic_fromto = altmusic_plut;
+	}
+	else
+	{
+		return;
+	}
+
+	// [crispy] chicken-out if only one lump is missing, something must be wrong
+	for (altmusic = altmusic_fromto; altmusic->from; altmusic++)
+	{
+		char name[9];
+
+		M_snprintf(name, sizeof(name), "d_%s", altmusic->to);
+
+		if (W_CheckNumForName(name) == -1)
+		{
+			return;
+		}
+	}
+
+	for (altmusic = altmusic_fromto; altmusic->from; altmusic++)
+	{
+		DEH_AddStringReplacement(altmusic->from, altmusic->to);
+	}
+}
+
 //
 // Initializes sound stuff, including volume
 // Sets channels, SFX and music volume,
@@ -169,7 +292,7 @@ void S_Init(int sfxVolume, int musicVolume)
     I_AtExit(S_Shutdown, true);
 
     // [crispy] initialize dedicated music tracks for the 4th episode
-    for (i = mus_e4m1; i <= mus_e4m9; i++)
+    for (i = mus_e4m1; i <= mus_e5m9; i++)
     {
         musicinfo_t *const music = &S_music[i];
         char namebuf[9];
@@ -177,6 +300,10 @@ void S_Init(int sfxVolume, int musicVolume)
         M_snprintf(namebuf, sizeof(namebuf), "d_%s", DEH_String(music->name));
         music->lumpnum = W_CheckNumForName(namebuf);
     }
+
+    // [crispy] add support for alternative music tracks for Final Doom's
+    // TNT and Plutonia as introduced in DoomMetalVol5.wad
+    S_RegisterAltMusic();
 }
 
 void S_Shutdown(void)
@@ -224,7 +351,7 @@ static void S_StopChannel(int cnum)
 // Kills playing sounds at start of level,
 //  determines music if any, changes music.
 //
-static short prevmap;
+static short prevmap = -1;
 
 void S_Start(void)
 {
@@ -285,7 +412,7 @@ void S_Start(void)
             mus_e1m9,        // Tim          e4m9
         };
 
-        if (gameepisode < 4)
+        if (gameepisode < 4 || gameepisode == 5) // [crispy] Sigil
         {
             mnum = mus_e1m1 + (gameepisode-1)*9 + gamemap-1;
         }
@@ -309,7 +436,7 @@ void S_Start(void)
     {
 	const short curmap = (gameepisode << 8) + gamemap;
 
-	if (prevmap == curmap)
+	if (prevmap == curmap || (nodrawers && singletics))
 	    return;
 
 	prevmap = curmap;
@@ -437,8 +564,8 @@ static int S_AdjustSoundParams(mobj_t *listener, mobj_t *source,
     fixed_t        ady;
     angle_t        angle;
 
-    // [crispy] proper sound clipping in Doom 2 MAP08 and The Ultimate Doom E4M8
-    const boolean doom1map8 = (gamemap == 8 && ((gamemode != commercial && gameepisode != 4) || !crispy->soundfix));
+    // [crispy] proper sound clipping in Doom 2 MAP08 and The Ultimate Doom E4M8 / Sigil E5M8
+    const boolean doom1map8 = (gamemap == 8 && ((gamemode != commercial && gameepisode < 4) || !crispy->soundfix));
 
     // calculate the distance to sound origin
     //  and clip it if necessary
@@ -525,15 +652,11 @@ void S_StartSound(void *origin_p, int sfx_id)
     int cnum;
     int volume;
 
-    // [crispy] play no sounds
-    if (nodrawers && singletics)
-	return;
-
     origin = (mobj_t *) origin_p;
     volume = snd_SfxVolume;
 
     // [crispy] make non-fatal, consider zero volume
-    if (sfx_id == sfx_None || !snd_SfxVolume)
+    if (sfx_id == sfx_None || !snd_SfxVolume || (nodrawers && singletics))
     {
         return;
     }
@@ -865,6 +988,13 @@ void S_ChangeMusic(int musicnum, int looping)
     handle = I_RegisterSong(music->data, W_LumpLength(music->lumpnum));
     music->handle = handle;
     I_PlaySong(handle, looping);
+    // [crispy] log played music
+    {
+        char name[9];
+        M_snprintf(name, sizeof(name), "%s", lumpinfo[music->lumpnum]->name);
+        fprintf(stderr, "S_ChangeMusic: %s (%s)\n", name,
+                W_WadNameForLump(lumpinfo[music->lumpnum]));
+    }
 
     mus_playing = music;
 
@@ -912,6 +1042,13 @@ void S_ChangeMusInfoMusic (int lumpnum, int looping)
     music->handle = I_RegisterSong(music->data, W_LumpLength(music->lumpnum));
 
     I_PlaySong(music->handle, looping);
+    // [crispy] log played music
+    {
+        char name[9];
+        M_snprintf(name, sizeof(name), "%s", lumpinfo[music->lumpnum]->name);
+        fprintf(stderr, "S_ChangeMusInfoMusic: %s (%s)\n", name,
+                W_WadNameForLump(lumpinfo[music->lumpnum]));
+    }
 
     mus_playing = music;
 
