@@ -433,6 +433,7 @@ cheatseq_t cheat_showfps = CHEAT("showfps", 0);
 cheatseq_t cheat_showfps2 = CHEAT("idrate", 0); // [crispy] PrBoom+
 cheatseq_t cheat_goobers = CHEAT("goobers", 0);
 cheatseq_t cheat_version = CHEAT("version", 0); // [crispy] Russian Doom
+cheatseq_t cheat_skill = CHEAT("skill", 0);
 static char msg[ST_MSGWIDTH];
 
 // [crispy] restrict cheat usage
@@ -459,7 +460,7 @@ void ST_Stop(void);
 void ST_refreshBackground(void)
 {
 
-    if (screenblocks >= CRISPY_HUD && !automapactive)
+    if (screenblocks >= CRISPY_HUD && (!automapactive || crispy->automapoverlay))
         return;
 
     if (st_statusbaron)
@@ -838,6 +839,7 @@ ST_Responder (event_t* ev)
       if (cht_CheckCheatSP(&cheat_powerup[7], ev->data2))
       {
 	memset(plyr->powers, 0, sizeof(plyr->powers));
+	plyr->mo->flags &= ~MF_SHADOW; // [crispy] cancel invisibility
 	plyr->message = DEH_String(STSTR_BEHOLDX);
       }
       
@@ -977,23 +979,29 @@ ST_Responder (event_t* ev)
 	    {
 		P_GivePower(plyr, pw_strength);
 		S_StartSound(NULL, sfx_getpow);
+		plyr->message = DEH_String(GOTBERSERK);
 	    }
 	    else
 	    {
 		plyr->powers[pw_strength] = 0;
+		plyr->message = DEH_String(STSTR_BEHOLDX);
 	    }
-
-	    M_snprintf(msg, sizeof(msg), DEH_String(STSTR_BEHOLDX));
 	}
 	else
 	{
 	    if (!plyr->weaponowned[w])
 	    {
 		extern boolean P_GiveWeapon (player_t* player, weapontype_t weapon, boolean dropped);
+		extern const char *const WeaponPickupMessages[NUMWEAPONS];
 
 		P_GiveWeapon(plyr, w, false);
 		S_StartSound(NULL, sfx_wpnup);
 
+		if (w > 1)
+		{
+		    plyr->message = DEH_String(WeaponPickupMessages[w]);
+		}
+
 		// [crispy] trigger evil grin now
 		plyr->bonuscount += 2;
 	    }
@@ -1010,12 +1018,15 @@ ST_Responder (event_t* ev)
 		    P_CheckAmmo(plyr);
 		}
 	    }
+	}
 
+	if (!plyr->message)
+	{
 	    M_snprintf(msg, sizeof(msg), "Weapon %s%d%s %s",
 	               crstr[CR_GOLD], w + 1, crstr[CR_NONE],
 	               plyr->weaponowned[w] ? "added" : "removed");
+	    plyr->message = msg;
 	}
-	plyr->message = msg;
       }
     }
 
@@ -1052,6 +1063,15 @@ ST_Responder (event_t* ev)
       plyr->message = msg;
       fprintf(stderr, "%s\n", msg);
     }
+    // [crispy] Show skill level
+    else if (cht_CheckCheat(&cheat_skill, ev->data2))
+    {
+      extern const char *skilltable[];
+
+      M_snprintf(msg, sizeof(msg), "Skill: %s",
+                 skilltable[BETWEEN(0,5,(int) gameskill+1)]);
+      plyr->message = msg;
+    }
     
     // 'clev' change-level cheat
     if (!netgame && !menuactive && cht_CheckCheatSP(&cheat_clev, ev->data2)) // [crispy] restrict cheat usage
@@ -1107,6 +1127,8 @@ ST_Responder (event_t* ev)
           }
           if (epsd > 4)
           {
+              // [crispy] Sigil
+              if (!(crispy->haved1e5 && epsd == 5))
               return false;
           }
           if (epsd == 4 && gameversion < exe_ultimate)
@@ -1119,7 +1141,7 @@ ST_Responder (event_t* ev)
               map = gamemap;
           }
           // [crispy] support E1M10 "Sewers"
-          if ((map == 0) && crispy->havee1m10 && epsd == 1)
+          if ((map == 0 || map > 9) && crispy->havee1m10 && epsd == 1)
           {
               map = 10;
           }
@@ -1498,7 +1520,9 @@ void ST_doPaletteStuff(void)
 {
 
     int		palette;
+#ifndef CRISPY_TRUECOLOR
     byte*	pal;
+#endif
     int		cnt;
     int		bzc;
 
@@ -1563,8 +1587,12 @@ void ST_doPaletteStuff(void)
     if (palette != st_palette)
     {
 	st_palette = palette;
+#ifndef CRISPY_TRUECOLOR
 	pal = (byte *) W_CacheLumpNum (lu_palette, PU_CACHE)+palette*768;
 	I_SetPalette (pal);
+#else
+	I_SetPalette (palette);
+#endif
     }
 
 }
@@ -2204,7 +2232,11 @@ void ST_Stop (void)
     if (st_stopped)
 	return;
 
+#ifndef CRISPY_TRUECOLOR
     I_SetPalette (W_CacheLumpNum (lu_palette, PU_CACHE));
+#else
+    I_SetPalette (0);
+#endif
 
     st_stopped = true;
 }
@@ -2212,7 +2244,7 @@ void ST_Stop (void)
 void ST_Init (void)
 {
     // [crispy] colorize the confusing 'behold' power-up menu
-    if (!strcmp(STSTR_BEHOLD, DEH_String(STSTR_BEHOLD)) &&
+    if (!DEH_HasStringReplacement(STSTR_BEHOLD) &&
         !M_ParmExists("-nodeh"))
     {
 	char str_behold[80];
