@@ -25,6 +25,7 @@
 #include "m_random.h"
 
 #include "deh_main.h"
+#include "deh_bexpars.h" // [crispy] bex_pars[]
 #include "i_swap.h"
 #include "i_system.h"
 
@@ -391,6 +392,8 @@ static patch_t*		bp[MAXPLAYERS];
 
  // Name graphics of each level (centered)
 static patch_t**	lnames;
+// [crispy] prevent crashes with maps without map title graphics lump
+static unsigned int	num_lnames;
 
 // Buffer storing the backdrop
 static patch_t *background;
@@ -419,8 +422,7 @@ void WI_drawLF(void)
     int y = WI_TITLEY;
 
     // [crispy] prevent crashes with maps without map title graphics lump
-    if ((gamemode == commercial && (unsigned)wbs->last >= NUMCMAPS) ||
-        (gamemode != commercial && (unsigned)wbs->last >= (crispy->havee1m10 ? NUMMAPS + 1 : NUMMAPS)))
+    if (wbs->last >= num_lnames || lnames[wbs->last] == NULL)
     {
         V_DrawPatch((ORIGWIDTH - SHORT(finished->width)) / 2, y, finished);
         return;
@@ -464,8 +466,7 @@ void WI_drawEL(void)
     int y = WI_TITLEY;
 
     // [crispy] prevent crashes with maps without map title graphics lump
-    if ((gamemode == commercial && (unsigned)wbs->next >= NUMCMAPS) ||
-        (gamemode != commercial && (unsigned)wbs->next >= (crispy->havee1m10 ? NUMMAPS + 1 : NUMMAPS)))
+    if (wbs->next >= num_lnames || lnames[wbs->next] == NULL)
     {
         return;
     }
@@ -802,6 +803,13 @@ static boolean		snl_pointeron = false;
 
 void WI_initShowNextLoc(void)
 {
+    // [crispy] display tally screen after ExM8
+    if ((gamemode != commercial) && (gamemap == 8))
+    {
+	G_WorldDone();
+	return;
+    }
+
     state = ShowNextLoc;
     acceleratestage = 0;
     cnt = SHOWNEXTLOCDELAY * TICRATE;
@@ -1491,7 +1499,6 @@ void WI_updateStats(void)
 // [crispy] conditionally draw par times on intermission screen
 static boolean WI_drawParTime (void)
 {
-	extern int bex_pars[4][10], bex_cpars[32];
 	extern lumpinfo_t *maplumpinfo;
 
 	boolean result = true;
@@ -1526,20 +1533,26 @@ static boolean WI_drawParTime (void)
 	{
 		// [crispy] IWAD: Episode 4 has no par times
 		// (but we have for singleplayer games)
-		if (wbs->epsd >= 4 && !crispy->singleplayer)
+		if (wbs->epsd == 3 && !crispy->singleplayer)
 		{
 			result = false;
 		}
 
 		// [crispy] IWAD/PWAD: BEX patch provided par times for Episode 4
 		// (disguised as par times for Doom II MAP02 to MAP10)
-		if (wbs->epsd >= 4 && bex_cpars[wbs->last + 1])
+		if (wbs->epsd == 3 && bex_cpars[wbs->last + 1])
 		{
 			result = true;
 		}
 
-		// [crispy] PWAD: BEX patch provided par times for Episodes 1-3
-		if (wbs->epsd < 4 && bex_pars[wbs->epsd + 1][wbs->last + 1])
+		// [crispy] IWAD/PWAD: BEX patch provided par times for Episodes 1-4
+		if (wbs->epsd <= 3 && bex_pars[wbs->epsd + 1][wbs->last + 1])
+		{
+			result = true;
+		}
+
+		// [crispy] PWAD: par times for Sigil
+		if (wbs->epsd == 4)
 		{
 			result = true;
 		}
@@ -1580,7 +1593,7 @@ void WI_drawStats(void)
         V_DrawPatch(ORIGWIDTH/2 + SP_TIMEX, SP_TIMEY, par);
 
         // Emulation: don't draw partime value if map33
-        if (true || gamemode != commercial || wbs->last != NUMCMAPS) // [crispy] always show
+        if (gamemode != commercial || wbs->last != NUMCMAPS)
         {
             WI_drawTime(ORIGWIDTH - SP_TIMEX, SP_TIMEY, cnt_par, true);
         }
@@ -1603,6 +1616,14 @@ void WI_drawStats(void)
     {
 	ST_DrawDemoTimer(leveltime);
     }
+
+    // [crispy] demo progress bar
+    if (demoplayback && crispy->demobar)
+    {
+	extern void HU_DemoProgressBar (void);
+
+	HU_DemoProgressBar();
+    }
 }
 
 void WI_checkForAccelerate(void)
@@ -1648,6 +1669,9 @@ void WI_Ticker(void)
 	// intermission music
   	if ( gamemode == commercial )
 	  S_ChangeMusic(mus_dm2int, true);
+	// [crispy] Sigil
+	else if (crispy->haved1e5 && wbs->epsd == 4 && W_CheckNumForName(DEH_String("D_SIGINT")) != -1)
+	  S_ChangeMusic(mus_sigint, true);
 	else
 	  S_ChangeMusic(mus_inter, true); 
     }
@@ -1838,11 +1862,21 @@ static void WI_loadUnloadData(load_callback_t callback)
     {
         M_StringCopy(name, DEH_String("INTERPIC"), sizeof(name));
     }
+    else if (crispy->haved1e5 && wbs->epsd == 4 && W_CheckNumForName(DEH_String("SIGILINT")) != -1) // [crispy] Sigil
+    {
+        M_StringCopy(name, DEH_String("SIGILINT"), sizeof(name));
+    }
     else
     {
 	DEH_snprintf(name, sizeof(name), "WIMAP%d", wbs->epsd);
     }
 
+    // [crispy] if still in doubt, use INTERPIC
+    if (W_CheckNumForName(name) == -1)
+    {
+        M_StringCopy(name, DEH_String("INTERPIC"), sizeof(name));
+    }
+
     // Draw backdrop and save to a temporary buffer
 
     callback(name, &background);
@@ -1850,7 +1884,11 @@ static void WI_loadUnloadData(load_callback_t callback)
 
 static void WI_loadCallback(const char *name, patch_t **variable)
 {
+  // [crispy] prevent crashes with maps without map title graphics lump
+  if (W_CheckNumForName(name) != -1)
     *variable = W_CacheLumpName(name, PU_STATIC);
+  else
+    *variable = NULL;
 }
 
 void WI_loadData(void)
@@ -1860,6 +1898,7 @@ void WI_loadData(void)
 	NUMCMAPS = (crispy->havemap33) ? 33 : 32;
 	lnames = (patch_t **) Z_Malloc(sizeof(patch_t*) * NUMCMAPS,
 				       PU_STATIC, NULL);
+	num_lnames = NUMCMAPS;
     }
     else
     {
@@ -1867,6 +1906,7 @@ void WI_loadData(void)
 	int nummaps = crispy->havee1m10 ? NUMMAPS + 1 : NUMMAPS;
 	lnames = (patch_t **) Z_Malloc(sizeof(patch_t*) * nummaps,
 				       PU_STATIC, NULL);
+	num_lnames = nummaps;
     }
 
     WI_loadUnloadData(WI_loadCallback);
