@@ -1793,6 +1793,22 @@ static default_t extra_defaults_list[] =
 
     CONFIG_VARIABLE_KEY(mouse_y_invert),
 
+    //!
+    // @game doom
+    //
+    // Automap overlay mode.
+    //
+
+    CONFIG_VARIABLE_INT(crispy_automapoverlay),
+
+    //!
+    // @game doom
+    //
+    // Automap rotate mode.
+    //
+
+    CONFIG_VARIABLE_INT(crispy_automaprotate),
+
     //!
     // @game doom
     //
