@@ -151,7 +151,7 @@ static void KeySetCallback(TXT_UNCAST_ARG(widget), TXT_UNCAST_ARG(variable))
 
 // Add a label and keyboard input to the specified table.
 
-static void AddKeyControl(TXT_UNCAST_ARG(table), char *name, int *var)
+static void AddKeyControl(TXT_UNCAST_ARG(table), const char *name, int *var)
 {
     TXT_CAST_ARG(txt_table_t, table);
     txt_key_input_t *key_input;
@@ -163,7 +163,7 @@ static void AddKeyControl(TXT_UNCAST_ARG(table), char *name, int *var)
     TXT_SignalConnect(key_input, "set", KeySetCallback, var);
 }
 
-static void AddSectionLabel(TXT_UNCAST_ARG(table), char *title,
+static void AddSectionLabel(TXT_UNCAST_ARG(table), const char *title,
                             boolean add_space)
 {
     TXT_CAST_ARG(txt_table_t, table);
